==> fyle_integrations_platform_connector-2.1.0-py3-none-any.whl: fyle_integrations_platform_connector/apis/merchants.py <==
import logging

from .base import Base
from typing import List
from fyle_accounting_mappings.models import ExpenseAttribute, ExpenseAttributesDeletionCache

logger = logging.getLogger(__name__)
logger.level = logging.INFO


class Merchants(Base):
    """
    Class for Merchants API
    """
    def __init__(self):
        Base.__init__(self, attribute_type='MERCHANT', query_params={'column_name':'eq.merchant'})

    def get(self):
        generator = self.get_all_generator()
        for items in generator:
            merchants = items['data'][0]

        return merchants

    def post(self, payload: List[str], skip_existing_merchants: bool = False, delete_merchants: bool = False):
        """
        Post data to Fyle
        """
        generator = self.get_all_generator()
        for items in generator:
            merchants = items['data'][0]
            if delete_merchants:
                merchants['options'] = list(set(merchants['options']) - set(payload))
            else:
                if skip_existing_merchants:
                    merchants['options'] = payload
                else:
                    merchants['options'].extend(payload)
                merchants['options'] = list(set(merchants['options']))
            merchant_payload = {
                'id': merchants['id'],
                'field_name': merchants['field_name'],
                'type': 'SELECT',
                'options': merchants['options'],
                'placeholder': merchants['placeholder'],
                'category_ids': merchants['category_ids'],
                'is_enabled': merchants['is_enabled'],
                'is_custom': merchants['is_custom'],
                'is_mandatory': merchants['is_mandatory'],
                'code': merchants['code'],
                'default_value': merchants['default_value'] if merchants['default_value'] else '',
            }

        return self.connection.post({'data': merchant_payload})

    def sync(self):
        """
        Syncs the latest API data to DB.
        """
        try:
            generator = self.get_all_generator()
            for items in generator:
                merchants = items['data'][0]

                ExpenseAttributesDeletionCache.objects.filter(workspace_id=self.workspace_id).update(merchant_list=merchants['options'])

                merchant_attributes = []

                for option in merchants['options']:
                    merchant_attributes.append({
                        'attribute_type': 'MERCHANT',
                        'display_name': 'Merchant',
                        'value': option,
                        'active': True,
                        'source_id': merchants['id'],
                    })

                self.bulk_create_or_update_expense_attributes(merchant_attributes, True)
            self.bulk_update_deleted_expense_attributes()

        except Exception as e:
            logger.exception(e)
            expense_attributes_deletion_cache = ExpenseAttributesDeletionCache.objects.get(workspace_id=self.workspace_id)
            expense_attributes_deletion_cache.merchant_ids = []
            expense_attributes_deletion_cache.save()

    def get_count(self):
        """
        Get the count of merchants
        """
        generator = self.get_all_generator()
        for items in generator:
            return len(items['data'][0]['options'])

        return 0

==> fyle_integrations_platform_connector-2.3.1-py3-none-any.whl: fyle_integrations_platform_connector/apis/merchants.py <==
from datetime import datetime, timezone
import logging

from .base import Base
from typing import List
from fyle_accounting_mappings.models import ExpenseAttributesDeletionCache

logger = logging.getLogger(__name__)
logger.level = logging.INFO


class Merchants(Base):
    """
    Class for Merchants API
    """
    def __init__(self):
        Base.__init__(self, attribute_type='MERCHANT', query_params={'column_name':'eq.merchant'})

    def get(self):
        generator = self.get_all_generator()
        for items in generator:
            merchants = items['data'][0]

        return merchants

    def post(self, payload: List[str], skip_existing_merchants: bool = False, delete_merchants: bool = False):
        """
        Post data to Fyle
        """
        logger.info("Merchant Payload received from Integration for Workspace: %s with count: %s", self.workspace_id, len(payload))
        generator = self.get_all_generator()
        for items in generator:
            merchants = items['data'][0]
            logger.info("Fyle Merchant Count: %s in Workspace: %s", len(merchants['options']), self.workspace_id)
            if delete_merchants:
                merchants['options'] = list(set(merchants['options']) - set(payload))
            else:
                if skip_existing_merchants:
                    merchants['options'] = payload
                else:
                    merchants['options'].extend(payload)
                merchants['options'] = list(set(merchants['options']))

            logger.info("Posting Merchant Payload for Workspace: %s with count: %s", self.workspace_id, len(merchants['options']))

            merchant_payload = {
                'id': merchants['id'],
                'field_name': merchants['field_name'],
                'type': 'SELECT',
                'options': merchants['options'],
                'placeholder': merchants['placeholder'],
                'category_ids': merchants['category_ids'],
                'is_enabled': merchants['is_enabled'],
                'is_custom': merchants['is_custom'],
                'is_mandatory': merchants['is_mandatory'],
                'code': merchants['code'],
                'default_value': merchants['default_value'] if merchants['default_value'] else '',
            }

            if len(merchant_payload['options']) == 0:
                logger.error("Merchant Payload is empty for Workspace: %s", self.workspace_id)
                return

        return self.connection.post({'data': merchant_payload})

    def sync(self):
        """
        Syncs the latest API data to DB.
        """
        try:
            expense_attributes_deletion_cache, _ = ExpenseAttributesDeletionCache.objects.get_or_create(workspace_id=self.workspace_id)
            generator = self.get_all_generator()
            for items in generator:
                merchants = items['data'][0]

                logger.info("Fyle Merchant Count: %s in Workspace: %s", len(merchants['options']), self.workspace_id)

                expense_attributes_deletion_cache.merchant_list = merchants['options']
                expense_attributes_deletion_cache.updated_at = datetime.now(timezone.utc)
                expense_attributes_deletion_cache.save(update_fields=['merchant_list', 'updated_at'])

                merchant_attributes = []

                for option in merchants['options']:
                    merchant_attributes.append({
                        'attribute_type': 'MERCHANT',
                        'display_name': 'Merchant',
                        'value': option,
                        'active': True,
                        'source_id': merchants['id'],
                    })

                self.bulk_create_or_update_expense_attributes(merchant_attributes, True)
            self.bulk_update_deleted_expense_attributes()

        except Exception as e:
            logger.exception(e)
            expense_attributes_deletion_cache = ExpenseAttributesDeletionCache.objects.get(workspace_id=self.workspace_id)
            expense_attributes_deletion_cache.merchant_ids = []
            expense_attributes_deletion_cache.updated_at = datetime.now(timezone.utc)
            expense_attributes_deletion_cache.save(update_fields=['merchant_ids', 'updated_at'])

    def get_count(self):
        """
        Get the count of merchants
        """
        generator = self.get_all_generator()
        for items in generator:
            return len(items['data'][0]['options'])

        return 0
